@@ -30,7 +30,7 @@ import traceback
 import uuid
 from asyncio import Future
 from collections.abc import Awaitable, Coroutine
-from datetime import datetime, timedelta, timezone, tzinfo
+from datetime import date, datetime, timedelta, timezone, tzinfo
 from http.client import responses
 from typing import Any, cast
 from urllib.parse import SplitResult, quote, unquote, urlsplit, urlunsplit
@@ -41,6 +41,7 @@ import orjson as json
 from ansi2html import Ansi2HTMLConverter  # type: ignore
 from blake3 import blake3  # type: ignore
 from bs4 import BeautifulSoup
+from dateutil.easter import easter
 from elasticsearch import AsyncElasticsearch
 from Levenshtein import distance  # type: ignore
 from redis.asyncio import Redis  # type: ignore
@@ -217,6 +218,9 @@ class BaseRequestHandler(RequestHandler):
         self,
     ) -> None:
         """Check authorization and call self.ratelimit()."""
+        # pylint: disable=attribute-defined-outside-init
+        self.now = await self.get_time()
+
         if self.request.method == "GET":
 
             if self.redirect_to_canonical_domain():
@@ -329,7 +333,7 @@ class BaseRequestHandler(RequestHandler):
                 blake3(bucket.encode("ascii")).hexdigest(),
             )
         if result[0]:
-            if (now := await self.get_time()).month == 4 and now.day == 20:
+            if self.now.date() == date(self.now.year, 4, 20):
                 self.set_status(420)
                 self.write_error(420)
             else:
@@ -430,13 +434,16 @@ class BaseRequestHandler(RequestHandler):
             str(uuid.uuid4()) if _user_id is None else _user_id.decode("ascii")
         )
         # save it in cookie or reset expiry date
-        self.set_secure_cookie(
-            "user_id",
-            user_id,
-            expires_days=90,
-            path="/",
-            samesite="Strict",
-        )
+        if not self.get_secure_cookie(
+            "user_id", max_age_days=30, min_version=2
+        ):
+            self.set_secure_cookie(
+                "user_id",
+                user_id,
+                expires_days=90,
+                path="/",
+                samesite="Strict",
+            )
         return user_id
 
     def get_module_infos(self) -> tuple[ModuleInfo, ...]:
@@ -444,7 +451,6 @@ class BaseRequestHandler(RequestHandler):
         return self.settings.get("MODULE_INFOS") or tuple()
 
     def fix_url(  # noqa: C901
-        # pylint: disable=too-complex, too-many-branches
         self,
         url: None | str | SplitResult = None,
         this_url: None | str = None,
@@ -459,10 +465,8 @@ class BaseRequestHandler(RequestHandler):
         """
         if url is None:
             url = self.request.full_url()
-
         if isinstance(url, str):
             url = urlsplit(url)
-
         if url.netloc and url.netloc.lower() != self.request.host.lower():
             this_url = this_url or self.request.full_url()
             if urlsplit(this_url).path == "/redirect":
@@ -472,23 +476,18 @@ class BaseRequestHandler(RequestHandler):
             url = urlsplit(
                 f"/redirect?to={quote(url.geturl())}&from={quote(this_url)}"
             )
-
+        path = new_path or url.path  # the path of the url
         # don't add as_json=nope to url if as_json is False
         # pylint: disable=compare-to-zero  # if None it shouldn't be deleted
         if "as_json" in query_args and query_args["as_json"] is False:
             del query_args["as_json"]
 
-        if (new_path or url.path).startswith("/static/"):
-            query_args["no_3rd_party"] = None
-            query_args["theme"] = None
-            query_args["dynload"] = None
+        if path.startswith(("/static/", "/soundboard/files/")):
+            query_args.update(no_3rd_party=None, theme=None, dynload=None)
         else:
-            if "no_3rd_party" not in query_args:
-                query_args["no_3rd_party"] = self.get_no_3rd_party()
-            if "theme" not in query_args:
-                query_args["theme"] = self.get_theme()
-            if "dynload" not in query_args:
-                query_args["dynload"] = self.get_dynload()
+            query_args.setdefault("no_3rd_party", self.get_no_3rd_party())
+            query_args.setdefault("theme", self.get_theme())
+            query_args.setdefault("dynload", self.get_dynload())
 
             if query_args["no_3rd_party"] == self.get_saved_no_3rd_party():
                 query_args["no_3rd_party"] = None
@@ -502,11 +501,7 @@ class BaseRequestHandler(RequestHandler):
                 (
                     self.request.protocol,
                     self.request.host,
-                    (
-                        "/redirect"
-                        if url.path == "/redirect"
-                        else new_path or url.path
-                    ).rstrip("/"),
+                    path.rstrip("/"),
                     url.query,
                     url.fragment,
                 )
@@ -516,9 +511,7 @@ class BaseRequestHandler(RequestHandler):
 
     def get_as_json(self) -> bool:
         """Get the value of the as_json query parameter."""
-        return str_to_bool(
-            self.get_query_argument("as_json", default="nope"), False
-        )
+        return str_to_bool(self.get_argument("as_json", default="nope"), False)
 
     def get_no_3rd_party_default(self) -> bool:
         """Get the default value for the no_3rd_party param."""
@@ -574,7 +567,6 @@ class BaseRequestHandler(RequestHandler):
         if "random" not in (theme := self.get_theme()):
             return theme
 
-        # theme names to ignore:
         ignore_themes = ["random", "random-dark"]
 
         if theme == "random-dark":
@@ -665,15 +657,6 @@ class HTMLRequestHandler(BaseRequestHandler):
 
     used_render = False
 
-    async def prepare(self) -> None:
-        # pylint: disable=attribute-defined-outside-init, invalid-name
-        await super().prepare()
-        c = self.get_cookie("c", None)
-        if c is None:
-            self.c = (now := await self.get_time()).month == 4 and now.day == 1
-        else:
-            self.c = str_to_bool(c, False)
-
     def get_form_appendix(self) -> str:
         """Get HTML to add to forms to keep important query args."""
         form_appendix: str
@@ -685,13 +668,11 @@ class HTMLRequestHandler(BaseRequestHandler):
             and self.get_no_3rd_party() != self.get_saved_no_3rd_party()
             else ""
         )
-
         if self.get_dynload() != self.get_saved_dynload():
             form_appendix += (
                 "<input name='dynload' class='hidden-input' "
                 f"value='{bool_to_str(self.get_dynload())}'>"
             )
-
         if (theme := self.get_theme()) != self.get_saved_theme():
             form_appendix += (
                 f"<input name='theme' class='hidden-input' value='{theme}'>"
@@ -721,8 +702,8 @@ class HTMLRequestHandler(BaseRequestHandler):
         They are mostly needed by most of the pages (like title,
         description and no_3rd_party).
         """
+        # pylint: disable=invalid-name
         namespace = super().get_template_namespace()
-
         namespace.update(
             {
                 "ansi2html": Ansi2HTMLConverter(inline=True, scheme="xterm"),
@@ -745,7 +726,7 @@ class HTMLRequestHandler(BaseRequestHandler):
                 "form_appendix": self.get_form_appendix(),
                 "fix_url": self.fix_url,
                 "fix_static": lambda url: self.fix_url(fix_static_url(url)),
-                "REPO_URL": self.fix_url(REPO_URL),
+                "REPO_URL": REPO_URL,
                 "theme": self.get_display_theme(),
                 "contact_address": self.get_contact_address(),
                 "elastic_rum_js_url": self.ELASTIC_RUM_JS_URL,
@@ -755,9 +736,15 @@ class HTMLRequestHandler(BaseRequestHandler):
                     else self.request.full_url().lower()
                 ).split("?")[0],
                 "settings": self.settings,
-                "c": self.c,
+                "c": self.now.date() == date(self.now.year, 4, 1)
+                if (c := self.get_cookie("c", None)) is None
+                else str_to_bool(c, False),
+                "🥚": timedelta()
+                <= self.now.date() - easter(self.now.year)
+                < timedelta(days=2),
                 "dynload": self.get_dynload(),
                 "as_json": self.get_as_json(),
+                "now": self.now,
             }
         )
         return namespace
@@ -872,16 +859,11 @@ class NotFoundHandler(HTMLRequestHandler):
 
     async def prepare(self) -> None:
         """Throw a 404 HTTP error or redirect to another page."""
-        # pylint: disable=attribute-defined-outside-init, invalid-name, too-complex
-        c = self.get_cookie("c", None)
-        if c is None:
-            self.c = (now := await self.get_time()).month == 4 and now.day == 1
-        else:
-            self.c = str_to_bool(c, False)
+        # pylint: disable=attribute-defined-outside-init
+        self.now = await self.get_time()  # used by get_template_namespace
 
         if self.request.method not in ("GET", "HEAD"):
             raise HTTPError(404)
-
         new_path = (
             re.sub(r"/+", "/", self.request.path.rstrip("/"))
             .replace("_", "-")
@@ -964,8 +946,7 @@ class ErrorPage(HTMLRequestHandler):
     async def get(self, code: str) -> None:
         """Show the error page."""
         status_code: int = int(code)
-        # get the reason
-        reason: str = responses.get(status_code, "")
+        reason: str = responses.get(status_code, "")  # get the reason
         # set the status code if Tornado doesn't raise an error if it is set
         if status_code not in (204, 304) and not 100 <= status_code < 200:
             self.set_status(status_code)  # set the status code
@@ -1019,9 +1000,11 @@ class ElasticRUM(BaseRequestHandler):
             self.redirect(self.fix_url(new_path), False)
             return
         if eggs:
-            self.set_header("Content-Type", "application/json")
+            self.set_header("Content-Type", "application/json; charset=UTF-8")
         else:
-            self.set_header("Content-Type", "application/javascript")
+            self.set_header(
+                "Content-Type", "application/javascript; charset=UTF-8"
+            )
             if spam:
                 self.set_header("SourceMap", self.URL + ".map")
         self.set_header(
